@@ -676,6 +676,10 @@ tunnelStart(ClientHttpRequest * http, int64_t * size_ptr, int *status_ptr)
         return;
     }
 
+    // record local IP:port for %<la and %<lp logging
+    if (comm_local_port(sock))
+        request->hier.peer_local_addr = fd_table[sock].local_addr;
+
     tunnelState = new TunnelStateData;
 #if DELAY_POOLS
 
